Exceptions
----------

:mod:`coredis.exceptions`

Authentication & Authorization
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. autoexception:: coredis.exceptions.AuthenticationFailureError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.AuthenticationRequiredError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.AuthorizationError
   :no-inherited-members:

Cluster Errors
^^^^^^^^^^^^^^
.. autoexception:: coredis.exceptions.AskError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.ClusterCrossSlotError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.ClusterDownError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.ClusterError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.ClusterResponseError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.ClusterRoutingError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.ClusterTransactionError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.MovedError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.RedisClusterException
   :no-inherited-members:
.. autoexception:: coredis.exceptions.TryAgainError
   :no-inherited-members:

Sentinel Errors
^^^^^^^^^^^^^^^
.. autoexception:: coredis.exceptions.PrimaryNotFoundError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.ReplicaNotFoundError
   :no-inherited-members:

Scripting Errors
^^^^^^^^^^^^^^^^
.. autoexception:: coredis.exceptions.NoScriptError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.FunctionError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.NotBusyError
   :no-inherited-members:


Stream Consumer Errors
^^^^^^^^^^^^^^^^^^^^^^
.. autoexception:: coredis.exceptions.StreamConsumerInitializationError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.StreamDuplicateConsumerGroupError
   :no-inherited-members:

General Exceptions
^^^^^^^^^^^^^^^^^^^
.. autoexception:: coredis.exceptions.BusyLoadingError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.CommandSyntaxError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.CommandNotSupportedError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.ModuleCommandNotSupportedError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.ConnectionError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.DataError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.ExecAbortError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.InvalidResponse
   :no-inherited-members:
.. autoexception:: coredis.exceptions.LockError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.LockAcquisitionError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.LockReleaseError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.LockExtensionError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.NoKeyError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.PersistenceError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.PubSubError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.ReadOnlyError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.RedisError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.ReplicationError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.ResponseError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.TimeoutError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.UnblockedError
   :no-inherited-members:
.. autoexception:: coredis.exceptions.WatchError
   :no-inherited-members:
